import React from "react";
import { FormSchema, ValidateFn, CompiledFormSchema, FormElementPrimitive } from "../types";
declare type Fields<T extends FormSchema> = CompiledFormSchema<T>["fields"];
declare type Groups<T extends FormSchema> = CompiledFormSchema<T>["groups"];
declare type WithPrev<T> = T | ((prev: T) => T);
interface BindOptions {
    ref?: React.Ref<FormElementPrimitive>;
    validate?: ValidateFn;
    onChange?: React.ChangeEventHandler<FormElementPrimitive>;
}
export interface FormixOptions<T extends FormSchema> {
    validateAfterMount?: boolean;
    resetErrorAfterInput?: boolean;
    formValidationDebounceTime?: number;
    validates?: Partial<Record<keyof Fields<T>, ValidateFn | null>>;
}
export interface UseFormixReturnType<T extends FormSchema> {
    ContextProvider: React.FC<React.PropsWithChildren<{}>>;
    bind(name: keyof Fields<T>, options?: BindOptions): {
        ref: React.RefCallback<FormElementPrimitive> | undefined;
        onChange: React.ChangeEventHandler<FormElementPrimitive>;
    };
    getValues(): Fields<T>;
    getValue<N extends keyof Fields<T>>(name: N): Fields<T>[N];
    setValue<N extends keyof Fields<T>>(name: N, value: WithPrev<Fields<T>[N]>): void;
    setErrors(errors: Partial<Record<keyof Fields<T>, string>>): void;
    validate(target?: keyof Groups<T>): Promise<boolean>;
    isValid(target?: keyof Groups<T>): Promise<boolean>;
    setError(name: keyof Fields<T>, error: string): void;
    getError(name: keyof Fields<T>): string;
    haveError(name: keyof Fields<T>): boolean;
    setValues(values: Partial<T>): void;
    getIsFormValid(): boolean;
    resetValues(): void;
    resetErrors(): void;
    reset(): void;
}
export declare function useFormix<T extends FormSchema>(schema: T, { validateAfterMount, resetErrorAfterInput, formValidationDebounceTime, validates, }?: FormixOptions<T>): UseFormixReturnType<T>;
export declare function useFormixContext<T extends FormSchema = any>(): Pick<UseFormixReturnType<T>, "bind" | "getValues" | "getValue" | "setValue" | "setErrors" | "validate" | "isValid" | "setError" | "getError" | "haveError" | "setValues" | "getIsFormValid" | "resetValues" | "resetErrors" | "reset">;
export {};
